Ablator Python Client
=====================

This is *karman* a Python Client for the [ablator](https://github.com/ablator/ablator) project. 

You can include karman.py in your code and use its `which` and `caniuse` methods.

You can also use karman_cli.py to test ablator directly from the command line. 
